@@ -1,14 +1,5 @@
 from pkg_resources import DistributionNotFound, get_distribution, parse_version
 
-try:
-    import psycopg2  # noqa: F401
-except ImportError:
-    raise ImportError(
-        'No module named psycopg2. Please install either '
-        'psycopg2 or psycopg2-binary package for CPython '
-        'or psycopg2cffi for Pypy.'
-    )
-
 for package in ['psycopg2', 'psycopg2-binary', 'psycopg2cffi']:
     try:
         if get_distribution(package).parsed_version < parse_version('2.5'):
@@ -19,9 +10,22 @@ for package in ['psycopg2', 'psycopg2-binary', 'psycopg2cffi']:
 
 __version__ = get_distribution('sqlalchemy-redshift').version
 
-from sqlalchemy.dialects import registry
+from sqlalchemy.dialects import registry  # noqa
 
-registry.register("redshift", "sqlalchemy_redshift.dialect", "RedshiftDialect")
 registry.register(
-    "redshift.psycopg2", "sqlalchemy_redshift.dialect", "RedshiftDialect"
+    "redshift", "sqlalchemy_redshift.dialect",
+    "RedshiftDialect_psycopg2"
+)
+registry.register(
+    "redshift.psycopg2", "sqlalchemy_redshift.dialect",
+    "RedshiftDialect_psycopg2"
+)
+registry.register(
+    'redshift+psycopg2cffi', 'sqlalchemy_redshift.dialect',
+    'RedshiftDialect_psycopg2cffi',
+)
+
+registry.register(
+    "redshift+redshift_connector", "sqlalchemy_redshift.dialect",
+    "RedshiftDialect_redshift_connector"
 )
