@@ -6,9 +6,13 @@ import pkg_resources
 import sqlalchemy as sa
 from sqlalchemy import inspect
 from sqlalchemy.dialects.postgresql.base import (
-    PGCompiler, PGDDLCompiler, PGIdentifierPreparer, PGTypeCompiler
+    PGCompiler, PGDDLCompiler, PGIdentifierPreparer, PGTypeCompiler,
+    PGExecutionContext, PGDialect
 )
 from sqlalchemy.dialects.postgresql.psycopg2 import PGDialect_psycopg2
+from sqlalchemy.dialects.postgresql.psycopg2cffi import PGDialect_psycopg2cffi
+from sqlalchemy.engine.default import DefaultDialect
+from sqlalchemy.sql.type_api import TypeEngine
 from sqlalchemy.engine import reflection
 from sqlalchemy.ext.compiler import compiles
 from sqlalchemy.sql.expression import (
@@ -26,6 +30,8 @@ from .commands import (
 from .ddl import (
     CreateMaterializedView, DropMaterializedView, get_table_attributes
 )
+import importlib
+import json
 
 sa_version = Version(sa.__version__)
 
@@ -61,10 +67,16 @@ __all__ = (
     'TIMESTAMP',
     'VARCHAR',
     'DOUBLE_PRECISION',
+    'GEOMETRY',
+    'SUPER',
     'TIMESTAMPTZ',
     'TIMETZ',
+    'HLLSKETCH',
 
-    'CopyCommand', 'UnloadFromSelect', 'RedshiftDialect', 'Compression',
+    'RedshiftDialect', 'RedshiftDialect_psycopg2',
+    'RedshiftDialect_psycopg2cffi', 'RedshiftDialect_redshift_connector',
+
+    'CopyCommand', 'UnloadFromSelect', 'Compression',
     'Encoding', 'Format', 'CreateLibraryCommand', 'AlterTableAppendCommand',
     'RefreshMaterializedView',
 
@@ -156,20 +168,33 @@ RESERVED_WORDS = set([
     "ignore", "ilike", "in", "initially", "inner", "intersect", "into",
     "is", "isnull", "join", "language", "leading", "left", "like",
     "limit", "localtime", "localtimestamp", "lun", "luns", "lzo", "lzop",
-    "minus", "mostly13", "mostly32", "mostly8", "natural", "new", "not",
+    "minus", "mostly16", "mostly32", "mostly8", "natural", "new", "not",
     "notnull", "null", "nulls", "off", "offline", "offset", "oid", "old",
     "on", "only", "open", "or", "order", "outer", "overlaps", "parallel",
-    "partition", "percent", "permissions", "placing", "primary", "raw",
-    "readratio", "recover", "references", "respect", "rejectlog",
+    "partition", "percent", "permissions", "pivot", "placing", "primary",
+    "raw", "readratio", "recover", "references", "respect", "rejectlog",
     "resort", "restore", "right", "select", "session_user", "similar",
     "snapshot", "some", "sysdate", "system", "table", "tag", "tdes",
     "text255", "text32k", "then", "timestamp", "to", "top", "trailing",
-    "true", "truncatecolumns", "union", "unique", "user", "using",
-    "verbose", "wallet", "when", "where", "with", "without",
+    "true", "truncatecolumns", "union", "unique", "unnest", "unpivot",
+    "user", "using", "verbose", "wallet", "when", "where", "with",
+    "without",
 ])
 
 
-class TIMESTAMPTZ(sa.dialects.postgresql.TIMESTAMP):
+class RedshiftTypeEngine(TypeEngine):
+
+    def _default_dialect(self, default=None):
+        """
+        Returns the default dialect used for TypeEngine compilation yielding
+        String result.
+
+        :meth:`~sqlalchemy.sql.type_api.TypeEngine.compile`
+        """
+        return RedshiftDialectMixin()
+
+
+class TIMESTAMPTZ(RedshiftTypeEngine, sa.dialects.postgresql.TIMESTAMP):
     """
     Redshift defines a TIMTESTAMPTZ column type as an alias
     of TIMESTAMP WITH TIME ZONE.
@@ -183,11 +208,14 @@ class TIMESTAMPTZ(sa.dialects.postgresql.TIMESTAMP):
 
     __visit_name__ = 'TIMESTAMPTZ'
 
-    def __init__(self):
-        super(TIMESTAMPTZ, self).__init__(timezone=True)
+    def __init__(self, timezone=True, precision=None):
+        # timezone param must be present as it's provided in base class so the
+        # object can be instantiated with kwargs. see
+        # :meth:`~sqlalchemy.dialects.postgresql.base.PGDialect._get_column_info`
+        super(TIMESTAMPTZ, self).__init__(timezone=True, precision=precision)
 
 
-class TIMETZ(sa.dialects.postgresql.TIME):
+class TIMETZ(RedshiftTypeEngine, sa.dialects.postgresql.TIME):
     """
     Redshift defines a TIMTETZ column type as an alias
     of TIME WITH TIME ZONE.
@@ -201,8 +229,87 @@ class TIMETZ(sa.dialects.postgresql.TIME):
 
     __visit_name__ = 'TIMETZ'
 
+    def __init__(self, timezone=True, precision=None):
+        # timezone param must be present as it's provided in base class so the
+        # object can be instantiated with kwargs. see
+        # :meth:`~sqlalchemy.dialects.postgresql.base.PGDialect._get_column_info`
+        super(TIMETZ, self).__init__(timezone=True, precision=precision)
+
+
+class GEOMETRY(RedshiftTypeEngine, sa.dialects.postgresql.TEXT):
+    """
+    Redshift defines a GEOMETRY column type
+    https://docs.aws.amazon.com/redshift/latest/dg/c_Supported_data_types.html
+
+    Adding an explicit type to the RedshiftDialect allows us follow the
+    SqlAlchemy conventions for "vendor-specific types."
+
+    https://docs.sqlalchemy.org/en/13/core/type_basics.html#vendor-specific-types
+    """
+    __visit_name__ = 'GEOMETRY'
+
     def __init__(self):
-        super(TIMETZ, self).__init__(timezone=True)
+        super(GEOMETRY, self).__init__()
+
+    def get_dbapi_type(self, dbapi):
+        return dbapi.GEOMETRY
+
+
+class SUPER(RedshiftTypeEngine, sa.dialects.postgresql.TEXT):
+    """
+    Redshift defines a SUPER column type
+    https://docs.aws.amazon.com/redshift/latest/dg/c_Supported_data_types.html
+
+    Adding an explicit type to the RedshiftDialect allows us follow the
+    SqlAlchemy conventions for "vendor-specific types."
+
+    https://docs.sqlalchemy.org/en/13/core/type_basics.html#vendor-specific-types
+    """
+
+    __visit_name__ = 'SUPER'
+
+    def __init__(self):
+        super(SUPER, self).__init__()
+
+    def get_dbapi_type(self, dbapi):
+        return dbapi.SUPER
+
+    def bind_expression(self, bindvalue):
+        return sa.func.json_parse(bindvalue)
+
+    def process_bind_param(self, value, dialect):
+        if not isinstance(value, str):
+            return json.dumps(value)
+        return value
+
+
+class HLLSKETCH(RedshiftTypeEngine, sa.dialects.postgresql.TEXT):
+    """
+    Redshift defines a HLLSKETCH column type
+    https://docs.aws.amazon.com/redshift/latest/dg/c_Supported_data_types.html
+
+    Adding an explicit type to the RedshiftDialect allows us follow the
+    SqlAlchemy conventions for "vendor-specific types."
+
+    https://docs.sqlalchemy.org/en/13/core/type_basics.html#vendor-specific-types
+    """
+    __visit_name__ = 'HLLSKETCH'
+
+    def __init__(self):
+        super(HLLSKETCH, self).__init__()
+
+    def get_dbapi_type(self, dbapi):
+        return dbapi.HLLSKETCH
+
+
+# Mapping for database schema inspection of Amazon Redshift datatypes
+REDSHIFT_ISCHEMA_NAMES = {
+    "geometry": GEOMETRY,
+    "super": SUPER,
+    "time with time zone": TIMETZ,
+    "timestamp with time zone": TIMESTAMPTZ,
+    "hllsketch": HLLSKETCH,
+}
 
 
 class RelationKey(namedtuple('RelationKey', ('name', 'schema'))):
@@ -420,18 +527,27 @@ class RedshiftDDLCompiler(PGDDLCompiler):
 
 class RedshiftTypeCompiler(PGTypeCompiler):
 
+    def visit_GEOMETRY(self, type_, **kw):
+        return "GEOMETRY"
+
+    def visit_SUPER(self, type_, **kw):
+        return "SUPER"
+
     def visit_TIMESTAMPTZ(self, type_, **kw):
         return "TIMESTAMPTZ"
 
     def visit_TIMETZ(self, type_, **kw):
         return "TIMETZ"
 
+    def visit_HLLSKETCH(self, type_, **kw):
+        return "HLLSKETCH"
+
 
 class RedshiftIdentifierPreparer(PGIdentifierPreparer):
     reserved_words = RESERVED_WORDS
 
 
-class RedshiftDialect(PGDialect_psycopg2):
+class RedshiftDialectMixin(DefaultDialect):
     """
     Define Redshift-specific behavior.
 
@@ -442,6 +558,9 @@ class RedshiftDialect(PGDialect_psycopg2):
 
     name = 'redshift'
     max_identifier_length = 127
+    # explicitly disables statement cache to disable warnings in logs
+    # ref: https://docs.sqlalchemy.org/en/14/core/connections.html#caching-for-third-party-dialects  # noqa
+    supports_statement_cache = False
 
     statement_compiler = RedshiftCompiler
     ddl_compiler = RedshiftDDLCompiler
@@ -469,11 +588,24 @@ class RedshiftDialect(PGDialect_psycopg2):
     ]
 
     def __init__(self, *args, **kw):
-        super(RedshiftDialect, self).__init__(*args, **kw)
+        super(RedshiftDialectMixin, self).__init__(*args, **kw)
         # Cache domains, as these will be static;
         # Redshift does not support user-created domains.
         self._domains = None
 
+    @property
+    def ischema_names(self):
+        """
+        Returns information about datatypes supported by Amazon Redshift.
+
+        Used in
+        :meth:`~sqlalchemy.engine.dialects.postgresql.base.PGDialect._get_column_info`.
+        """
+        return {
+            **super(RedshiftDialectMixin, self).ischema_names,
+            **REDSHIFT_ISCHEMA_NAMES
+        }
+
     @reflection.cache
     def get_columns(self, connection, table_name, schema=None, **kw):
         """
@@ -654,26 +786,6 @@ class RedshiftDialect(PGDialect_psycopg2):
             'redshift_interleaved_sortkey': interleaved_sortkey,
         }
 
-    def create_connect_args(self, *args, **kwargs):
-        """
-        Build DB-API compatible connection arguments.
-
-        Overrides interface
-        :meth:`~sqlalchemy.engine.interfaces.Dialect.create_connect_args`.
-        """
-        default_args = {
-            'sslmode': 'verify-full',
-            'sslrootcert': pkg_resources.resource_filename(
-                __name__,
-                'redshift-ca-bundle.crt'
-            ),
-        }
-        cargs, cparams = super(RedshiftDialect, self).create_connect_args(
-            *args, **kwargs
-        )
-        default_args.update(cparams)
-        return cargs, default_args
-
     def _get_table_or_view_names(self, relkind, connection, schema=None, **kw):
         default_schema = inspect(connection).default_schema_name
         if not schema:
@@ -700,7 +812,7 @@ class RedshiftDialect(PGDialect_psycopg2):
         elif sa_version >= Version('1.4.0') and 'identity' not in kw:
             kw['identity'] = None
 
-        column_info = super(RedshiftDialect, self)._get_column_info(
+        column_info = super(RedshiftDialectMixin, self)._get_column_info(
             *args,
             **kw
         )
@@ -750,7 +862,7 @@ class RedshiftDialect(PGDialect_psycopg2):
 
     @reflection.cache
     def _get_all_relation_info(self, connection, **kw):
-        result = connection.execute("""
+        result = connection.execute(sa.text("""
         SELECT
           c.relkind,
           n.oid as "schema_oid",
@@ -771,7 +883,7 @@ class RedshiftDialect(PGDialect_psycopg2):
         WHERE c.relkind IN ('r', 'v', 'm', 'S', 'f')
           AND n.nspname !~ '^pg_'
         ORDER BY c.relkind, n.oid, n.nspname;
-        """)
+        """))
         relations = {}
         for rel in result:
             key = RelationKey(rel.relname, rel.schema, connection)
@@ -788,72 +900,71 @@ class RedshiftDialect(PGDialect_psycopg2):
             "AND schema = '{schema}'".format(schema=schema) if schema else ""
         )
         all_columns = defaultdict(list)
-        with connection.connect() as cc:
-            result = cc.execute("""
-            SELECT
-              n.nspname as "schema",
-              c.relname as "table_name",
-              att.attname as "name",
-              format_encoding(att.attencodingtype::integer) as "encode",
-              format_type(att.atttypid, att.atttypmod) as "type",
-              att.attisdistkey as "distkey",
-              att.attsortkeyord as "sortkey",
-              att.attnotnull as "notnull",
-              pg_catalog.col_description(att.attrelid, att.attnum)
-                as "comment",
-              adsrc,
-              attnum,
-              pg_catalog.format_type(att.atttypid, att.atttypmod),
-              pg_catalog.pg_get_expr(ad.adbin, ad.adrelid) AS DEFAULT,
-              n.oid as "schema_oid",
-              c.oid as "table_oid"
-            FROM pg_catalog.pg_class c
-            LEFT JOIN pg_catalog.pg_namespace n
-              ON n.oid = c.relnamespace
-            JOIN pg_catalog.pg_attribute att
-              ON att.attrelid = c.oid
-            LEFT JOIN pg_catalog.pg_attrdef ad
-              ON (att.attrelid, att.attnum) = (ad.adrelid, ad.adnum)
-            WHERE n.nspname !~ '^pg_'
-              AND att.attnum > 0
-              AND NOT att.attisdropped
-              {schema_clause}
-            UNION
-            SELECT
-              view_schema as "schema",
-              view_name as "table_name",
-              col_name as "name",
-              null as "encode",
-              col_type as "type",
-              null as "distkey",
-              0 as "sortkey",
-              null as "notnull",
-              null as "comment",
-              null as "adsrc",
-              null as "attnum",
-              col_type as "format_type",
-              null as "default",
-              null as "schema_oid",
-              null as "table_oid"
-            FROM pg_get_late_binding_view_cols() cols(
-              view_schema name,
-              view_name name,
-              col_name name,
-              col_type varchar,
-              col_num int)
-            WHERE 1 {schema_clause}
-            ORDER BY "schema", "table_name", "attnum";
-            """.format(schema_clause=schema_clause)
-            )
-            for col in result:
-                key = RelationKey(col.table_name, col.schema, connection)
-                all_columns[key].append(col)
+        result = connection.execute(sa.text("""
+        SELECT
+          n.nspname as "schema",
+          c.relname as "table_name",
+          att.attname as "name",
+          format_encoding(att.attencodingtype::integer) as "encode",
+          format_type(att.atttypid, att.atttypmod) as "type",
+          att.attisdistkey as "distkey",
+          att.attsortkeyord as "sortkey",
+          att.attnotnull as "notnull",
+          pg_catalog.col_description(att.attrelid, att.attnum)
+            as "comment",
+          adsrc,
+          attnum,
+          pg_catalog.format_type(att.atttypid, att.atttypmod),
+          pg_catalog.pg_get_expr(ad.adbin, ad.adrelid) AS DEFAULT,
+          n.oid as "schema_oid",
+          c.oid as "table_oid"
+        FROM pg_catalog.pg_class c
+        LEFT JOIN pg_catalog.pg_namespace n
+          ON n.oid = c.relnamespace
+        JOIN pg_catalog.pg_attribute att
+          ON att.attrelid = c.oid
+        LEFT JOIN pg_catalog.pg_attrdef ad
+          ON (att.attrelid, att.attnum) = (ad.adrelid, ad.adnum)
+        WHERE n.nspname !~ '^pg_'
+          AND att.attnum > 0
+          AND NOT att.attisdropped
+          {schema_clause}
+        UNION
+        SELECT
+          view_schema as "schema",
+          view_name as "table_name",
+          col_name as "name",
+          null as "encode",
+          col_type as "type",
+          null as "distkey",
+          0 as "sortkey",
+          null as "notnull",
+          null as "comment",
+          null as "adsrc",
+          null as "attnum",
+          col_type as "format_type",
+          null as "default",
+          null as "schema_oid",
+          null as "table_oid"
+        FROM pg_get_late_binding_view_cols() cols(
+          view_schema name,
+          view_name name,
+          col_name name,
+          col_type varchar,
+          col_num int)
+        WHERE 1 {schema_clause}
+        ORDER BY "schema", "table_name", "attnum";
+        """.format(schema_clause=schema_clause))
+        )
+        for col in result:
+            key = RelationKey(col.table_name, col.schema, connection)
+            all_columns[key].append(col)
 
         return dict(all_columns)
 
     @reflection.cache
     def _get_all_constraint_info(self, connection, **kw):
-        result = connection.execute("""
+        result = connection.execute(sa.text("""
         SELECT
           n.nspname as "schema",
           c.relname as "table_name",
@@ -874,7 +985,7 @@ class RedshiftDialect(PGDialect_psycopg2):
           ON t.conrelid = a.attrelid AND a.attnum = ANY(t.conkey)
         WHERE n.nspname !~ '^pg_'
         ORDER BY n.nspname, c.relname
-        """)
+        """))
         all_constraints = defaultdict(list)
         for con in result:
             key = RelationKey(con.table_name, con.schema, connection)
@@ -882,6 +993,241 @@ class RedshiftDialect(PGDialect_psycopg2):
         return all_constraints
 
 
+class Psycopg2RedshiftDialectMixin(RedshiftDialectMixin):
+    """
+    Define behavior specific to ``psycopg2``.
+
+    Most public methods are overrides of the underlying interfaces defined in
+    :class:`~sqlalchemy.engine.interfaces.Dialect` and
+    :class:`~sqlalchemy.engine.Inspector`.
+    """
+    def create_connect_args(self, *args, **kwargs):
+        """
+        Build DB-API compatible connection arguments.
+
+        Overrides interface
+        :meth:`~sqlalchemy.engine.interfaces.Dialect.create_connect_args`.
+        """
+        default_args = {
+            'sslmode': 'verify-full',
+            'sslrootcert': pkg_resources.resource_filename(
+                __name__,
+                'redshift-ca-bundle.crt'
+            ),
+        }
+        cargs, cparams = (
+            super(Psycopg2RedshiftDialectMixin, self).create_connect_args(
+                *args, **kwargs
+            )
+        )
+        default_args.update(cparams)
+        return cargs, default_args
+
+    @classmethod
+    def dbapi(cls):
+        try:
+            return importlib.import_module(cls.driver)
+        except ImportError:
+            raise ImportError(
+                'No module named {}'.format(cls.driver)
+            )
+
+
+class RedshiftDialect_psycopg2(
+    Psycopg2RedshiftDialectMixin, PGDialect_psycopg2
+):
+    pass
+
+
+# Add RedshiftDialect synonym for backwards compatibility.
+RedshiftDialect = RedshiftDialect_psycopg2
+
+
+class RedshiftDialect_psycopg2cffi(
+    Psycopg2RedshiftDialectMixin, PGDialect_psycopg2cffi
+):
+    pass
+
+
+class RedshiftDialect_redshift_connector(RedshiftDialectMixin, PGDialect):
+
+    class RedshiftCompiler_redshift_connector(RedshiftCompiler, PGCompiler):
+        def limit_clause(self, select, **kw):
+            text = ""
+            if select._limit_clause is not None:
+                # an integer value for limit is retrieved
+                text += " \n LIMIT " + str(select._limit)
+            if select._offset_clause is not None:
+                if select._limit_clause is None:
+                    text += "\n LIMIT ALL"
+                # an integer value for offset is retrieved
+                text += " OFFSET " + str(select._offset)
+            return text
+
+        def visit_mod_binary(self, binary, operator, **kw):
+            return (
+                self.process(binary.left, **kw)
+                + " %% "
+                + self.process(binary.right, **kw)
+            )
+
+        def post_process_text(self, text):
+            from sqlalchemy import util
+            if "%%" in text:
+                util.warn(
+                    "The SQLAlchemy postgresql dialect "
+                    "now automatically escapes '%' in text() "
+                    "expressions to '%%'."
+                )
+            return text.replace("%", "%%")
+
+    class RedshiftExecutionContext_redshift_connector(PGExecutionContext):
+        def pre_exec(self):
+            if not self.compiled:
+                return
+
+    driver = 'redshift_connector'
+
+    supports_unicode_statements = True
+
+    supports_unicode_binds = True
+
+    default_paramstyle = "format"
+    supports_sane_multi_rowcount = True
+    statement_compiler = RedshiftCompiler_redshift_connector
+    execution_ctx_cls = RedshiftExecutionContext_redshift_connector
+
+    supports_statement_cache = True
+    use_setinputsizes = False  # not implemented in redshift_connector
+
+    def __init__(self, client_encoding=None, **kwargs):
+        super(
+            RedshiftDialect_redshift_connector, self
+        ).__init__(client_encoding=client_encoding, **kwargs)
+        self.client_encoding = client_encoding
+
+    @classmethod
+    def dbapi(cls):
+        try:
+            driver_module = importlib.import_module(cls.driver)
+
+            # Starting v2.0.908 driver converts description column names to str
+            if Version(driver_module.__version__) < Version('2.0.908'):
+                cls.description_encoding = "use_encoding"
+            else:
+                cls.description_encoding = None
+
+            return driver_module
+        except ImportError:
+            raise ImportError(
+                'No module named redshift_connector. Please install '
+                'redshift_connector to use this sqlalchemy dialect.'
+            )
+
+    def set_client_encoding(self, connection, client_encoding):
+        """
+        Sets the client-side encoding using the provided connection object.
+        """
+        # adjust for ConnectionFairy possibly being present
+        if hasattr(connection, "connection"):
+            connection = connection.connection
+
+        cursor = connection.cursor()
+        cursor.execute("SET CLIENT_ENCODING TO '" + client_encoding + "'")
+        cursor.execute("COMMIT")
+        cursor.close()
+
+    def set_isolation_level(self, connection, level):
+        """
+        Sets the isolation level for the current transaction.
+
+        Additionally, autocommit can be enabled on the underlying
+        db-api connection object via argument level='AUTOCOMMIT'.
+
+        See Amazon Redshift documentation for information on supported
+        isolation levels.
+        https://docs.aws.amazon.com/redshift/latest/dg/r_BEGIN.html
+        """
+        level = level.replace("_", " ")
+
+        # adjust for ConnectionFairy possibly being present
+        if hasattr(connection, "connection"):
+            connection = connection.connection
+
+        if level == "AUTOCOMMIT":
+            connection.autocommit = True
+        else:
+            connection.autocommit = False
+            super(
+                RedshiftDialect_redshift_connector, self
+            ).set_isolation_level(connection, level)
+
+    def on_connect(self):
+        fns = []
+
+        def on_connect(conn):
+            from sqlalchemy.sql.elements import quoted_name
+            from sqlalchemy import util
+            conn.py_types[quoted_name] = conn.py_types[util.text_type]
+
+        fns.append(on_connect)
+
+        if self.client_encoding is not None:
+
+            def on_connect(conn):
+                self.set_client_encoding(conn, self.client_encoding)
+
+            fns.append(on_connect)
+
+        if self.isolation_level is not None:
+
+            def on_connect(conn):
+                self.set_isolation_level(conn, self.isolation_level)
+
+            fns.append(on_connect)
+
+        if len(fns) > 0:
+
+            def on_connect(conn):
+                for fn in fns:
+                    fn(conn)
+
+            return on_connect
+        else:
+            return None
+
+    def create_connect_args(self, *args, **kwargs):
+        """
+        Build DB-API compatible connection arguments.
+
+        Overrides interface
+        :meth:`~sqlalchemy.engine.interfaces.Dialect.create_connect_args`.
+        """
+        default_args = {
+            'sslmode': 'verify-full',
+            'ssl': True,
+            'application_name': 'sqlalchemy-redshift'
+        }
+        cargs, cparams = super(RedshiftDialectMixin, self).create_connect_args(
+            *args, **kwargs
+        )
+        # set client_encoding so it is picked up by on_connect(), as
+        # redshift_connector does not have client_encoding connection parameter
+        self.client_encoding = cparams.pop(
+            'client_encoding', self.client_encoding
+        )
+
+        if 'port' in cparams:
+            cparams['port'] = int(cparams['port'])
+
+        if 'username' in cparams:
+            cparams['user'] = cparams['username']
+            del cparams['username']
+
+        default_args.update(cparams)
+        return cargs, default_args
+
+
 def gen_columns_from_children(root):
     """
     Generates columns that are being used in child elements of the delete query
@@ -924,7 +1270,7 @@ def visit_delete_stmt(element, compiler, **kwargs):
     problem illustration:
 
     >>> from sqlalchemy import Table, Column, Integer, MetaData, delete
-    >>> from sqlalchemy_redshift.dialect import RedshiftDialect
+    >>> from sqlalchemy_redshift.dialect import RedshiftDialect_psycopg2
     >>> meta = MetaData()
     >>> table1 = Table(
     ... 'table_1',
@@ -939,7 +1285,7 @@ def visit_delete_stmt(element, compiler, **kwargs):
     ... )
     ...
     >>> del_stmt = delete(table1).where(table1.c.pk==table2.c.pk)
-    >>> str(del_stmt.compile(dialect=RedshiftDialect()))
+    >>> str(del_stmt.compile(dialect=RedshiftDialect_psycopg2()))
     'DELETE FROM table_1 USING table_2 WHERE table_1.pk = table_2.pk'
     >>> str(del_stmt)
     'DELETE FROM table_1 , table_2 WHERE table_1.pk = table_2.pk'
@@ -949,7 +1295,7 @@ def visit_delete_stmt(element, compiler, **kwargs):
     >>> del_stmt3 = delete(table1).where(table1.c.pk > 1000)
     >>> str(del_stmt3)
     'DELETE FROM table_1 WHERE table_1.pk > :pk_1'
-    >>> str(del_stmt3.compile(dialect=RedshiftDialect()))
+    >>> str(del_stmt3.compile(dialect=RedshiftDialect_psycopg2()))
     'DELETE FROM table_1 WHERE table_1.pk >  %(pk_1)s'
     """
 
